These are cvss schemas found [here](https://nvd.nist.gov/developers/vulnerabilities) that are referenced in the main NVD schema.

Local copies have been made to ensure that schema valiations can be performed without network access being required.

This is facilitated by loading the file-to-url mapping in the test fixture (in conftest.py) that is responsible for json schema validation.
